document.addEventListener('DOMContentLoaded', () => {
  const questions = [
    {
      text: "What's your primary goal?",
      options: [
        { text: "Long-term organic growth", score: "seo" },
        { text: "Immediate results", score: "ppc" },
        { text: "Both", score: "neutral" }
      ]
    },
    {
      text: "What's your monthly marketing budget?",
      options: [
        { text: "Less than $500", score: "seo" },
        { text: "More than $2000", score: "ppc" },
        { text: "$500-$2000", score: "neutral" }
      ]
    },
    {
      text: "How competitive is your industry?",
      options: [
        { text: "Very competitive", score: "ppc" },
        { text: "Moderately competitive", score: "neutral" },
        { text: "Not very competitive", score: "seo" }
      ]
    }
  ];

  let currentQuestion = 0;
  let scores = { seo: 0, ppc: 0, neutral: 0 };

  const questionContainer = document.querySelector('.question-container');
  const progressBar = document.querySelector('.progress');
  const resultContainer = document.querySelector('.result-container');
  const resultDiv = document.querySelector('.result');
  const restartBtn = document.querySelector('.restart-btn');

  function showQuestion(index) {
    const question = questions[index];
    questionContainer.innerHTML = `
      <div class="question" data-question="${index + 1}">
        <h3>${question.text}</h3>
        <div class="options">
          ${question.options.map(option => `
            <button data-score="${option.score}">${option.text}</button>
          `).join('')}
        </div>
      </div>
    `;

    progressBar.style.width = `${((index + 1) / questions.length) * 100}%`;

    const optionButtons = questionContainer.querySelectorAll('button');
    optionButtons.forEach(button => {
      button.addEventListener('click', handleAnswer);
    });
  }

  function handleAnswer(e) {
    const score = e.target.dataset.score;
    scores[score]++;
    currentQuestion++;

    if (currentQuestion < questions.length) {
      showQuestion(currentQuestion);
    } else {
      showResult();
    }
  }

  function showResult() {
    questionContainer.classList.add('hidden');
    resultContainer.classList.remove('hidden');

    const recommendation = getRecommendation();
    resultDiv.innerHTML = `
      <h4>${recommendation.title}</h4>
      <p>${recommendation.description}</p>
    `;
  }

  function getRecommendation() {
    if (scores.seo > scores.ppc) {
      return {
        title: "SEO is Your Best Choice!",
        description: "Based on your answers, focusing on SEO would be most beneficial for your website. This will help you build long-term organic traffic and sustainable growth."
      };
    } else if (scores.ppc > scores.seo) {
      return {
        title: "PPC is Your Best Choice!",
        description: "Based on your answers, PPC would be most effective for your needs. This will help you achieve quick results and precise targeting."
      };
    } else {
      return {
        title: "Consider a Hybrid Approach",
        description: "Based on your answers, a combination of both SEO and PPC would work best for your situation. This will give you both immediate results and long-term benefits."
      };
    }
  }

  restartBtn.addEventListener('click', () => {
    currentQuestion = 0;
    scores = { seo: 0, ppc: 0, neutral: 0 };
    resultContainer.classList.add('hidden');
    questionContainer.classList.remove('hidden');
    showQuestion(0);
  });

  showQuestion(0);
});
